@@ -119,9 +119,9 @@ int liqapp_prefs_load()
 							else
 								break;
 						}
-						
+						//liqapp_log("pref: '%s'='%s'",line,data);
 	
-						liqcell_child_insertsorted( prefsroot, qpref(line,data) );
+						liqcell_child_insertsorted( prefsroot, qpref(line,strdup(data)) );
 						
 
 					}
@@ -165,15 +165,31 @@ char * liqapp_pref_setvalue_printf(char *prefkey,char *prefformat, ...)
 
 char * liqapp_pref_setvalue(char *prefkey,char *prefvalue)
 {
+	if(prefvalue)	prefvalue=strdup(prefvalue);
 	liqcell *p=liqcell_child_lookup(prefsroot,prefkey);
 	if(p)
 	{
+		char *x=liqcell_getdata(p); if(x)free(x);
 		liqcell_setdata(p,prefvalue);
 		return prefvalue;
 	}
 	liqcell_child_insertsorted( prefsroot, qpref(prefkey,prefvalue) );
 	return NULL;
 }
+char * liqapp_pref_getvalue_def(char *prefkey,char *defaultifmissing)
+{
+	liqcell *p=liqcell_child_lookup(prefsroot,prefkey);
+	if(p)
+	{
+		return liqcell_getdata(p);
+	}
+	else
+	{
+		return defaultifmissing;
+	}
+	return NULL;
+}
+
 char * liqapp_pref_getvalue(char *prefkey)
 {
 	liqcell *p=liqcell_child_lookup(prefsroot,prefkey);
@@ -220,7 +236,7 @@ int liqapp_prefs_save()
 		liqcell *c=prefsroot->linkchild;
 		while(c)
 		{
-			fprintf(fn,"\t%s=%s\n",c->name,liqcell_getdata(c));		// todo ensure multiline data pushed ok, and pulled and extracted correctly
+			fprintf(fn,"\t%s=%s\n",c->name,(char *)liqcell_getdata(c));		// todo ensure multiline data pushed ok, and pulled and extracted correctly
 			c=c->linknext;
 		}
 		fprintf(fn,"end\n");
